==> FitGallery-0.80.tar.gz: FitGallery-0.80/ver_thumb.php <==
<?php

# FitGallery 0.80 copyleft GPL by Pollo (magura@ardilla.dyndns.org) and Presi (presi@confluencia.net)
# http://fitgallery.presi.org

# view thumbs page file

include 'config-dirgal.php';
include 'config.php';
include 'config-lang.php';

$version="0.80";
$galeria=basename($_GET["galeria"]);
$dirimgs="imgs";
$semiruta=$dirgal."/".$galeria;
$lineas=file($semiruta."/".$titulo);
$ruta=$semiruta."/".$dirimgs;
$n=0;
$total=0;


echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery 0.80 copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->
<html>
<head>
<style type="text/css">
<!--';
if (file_exists('ver_thumb.css.php')) { include 'ver_thumb.css.php'; }
else { include 'default.css.php'; }
echo '-->
</style>
<title>'.$lineas[0].'</title>
</head>
<body>
<h3 class="center">'.$lineas[0].'</h3>
';


$handle=opendir($ruta); 
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != "..")
  {
    $arr[$n][0]=filemtime("$ruta/$file");
    $arr[$n][1]=$file;
    $arr[$n][2]=filesize("$ruta/$file");
    $total += $arr[$n][2];
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n";

$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];	
   $size=getimagesize("$ruta/$valor");
   $bytes=$arr[$i][2];
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);

   echo "
   <div class=\"figure\">
   <p class=\"caption\">
   <a href=\"$ruta/$valor\">
   <img class=\"sinborde\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_thumb&amp;tipo=t\" alt=\"$valor\">
   </a>";
   if ($h_medium>0) 
     echo "<br><a class=\"texto\" href=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_medium&amp;tipo=m\">$text_medium</a>";
   echo "</p>";
   echo "<p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"$ruta/$valor\">
   $valor<br>
   </a>
   $size[0]x$size[1]<br>
   $bytes bytes<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo "
<p class=\"clear\">
<br>
<strong>$text_galerias</strong>";

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '</p>
<p class="clear">
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo $text_anterior;
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$anterior\">$text_anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo $text_siguiente;
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$siguiente\">$text_siguiente</a>";
echo "</p>
<p class=\"center\">
$text_totales$total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>";

if (powered) echo "<p class=\"center\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "</body>
</html>";

?>

==> FitGallery-0.81.tar.gz: FitGallery-0.81/ver_thumb.php <==
<?php

# FitGallery 0.81 copyleft GPL by Pollo (magura@ardilla.dyndns.org) and Presi (presi@confluencia.net)
# http://fitgallery.presi.org

# view thumbs page file

include 'config/config-thumb.php';
include 'config/config.php';
include 'config/config-lang.php';

$version="0.81";
$galeria=basename($_GET["galeria"]);
$dirimgs="imgs";
$semiruta=$dirgal."/".$galeria;
$file_titulo=$semiruta."/".$titulo;
$linea_titulo=file($file_titulo);
$file_subtitulo=$semiruta."/".$subtitulo;
$ruta=$semiruta."/".$dirimgs;
$n=0;
$total=0;


echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery 0.81 copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->
<html>
<head>
<style type="text/css">
<!--';
if (file_exists('config/ver_thumb.css.php')) { include 'config/ver_thumb.css.php'; }
else { include 'config/default.css.php'; }
echo '-->
</style>
<title>'.strip_tags($linea_titulo[0]).'</title>
</head>
<body>
<h3 class="center">';
include "$file_titulo";
echo '</h3>
';


$handle=opendir($ruta); 
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != "..")
  {
    $arr[$n][0]=filemtime("$ruta/$file");
    $arr[$n][1]=$file;
    $arr[$n][2]=filesize("$ruta/$file");
    $total += $arr[$n][2];
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n
<h4 class=\"center\">";
include "$file_subtitulo";
echo "</h4>\n";


$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];	
   $size=getimagesize("$ruta/$valor");
   $bytes=$arr[$i][2];
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);

   echo "
   <div class=\"figure\">
   <p class=\"caption\">
   <a href=\"$ruta/$valor\">
   <img class=\"sinborde\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_thumb&amp;tipo=t\" alt=\"$valor\">
   </a>";
   if ($h_medium>0) 
     echo "<br><a class=\"texto\" href=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_medium&amp;tipo=m\">$text_medium</a>";
   echo "</p>";
   echo "<p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"$ruta/$valor\">
   $valor<br>
   </a>
   $size[0]x$size[1]<br>
   $bytes bytes<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo "
<p class=\"clear\">
<br>";
if (file_exists('ver_gals.php')) echo "<a href=\"ver_gals.php\">$text_galerias</a> | ";
echo "<strong>$text_pages:</strong> ";

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '<br>
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo $text_anterior;
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$anterior\">$text_anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo $text_siguiente;
            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$siguiente\">$text_siguiente</a>";
echo "</p>
<p class=\"center\">
$text_totales$total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>";

if (powered) echo "<p class=\"center\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "</body>
</html>";

?>
